---
title: <span class="badge object-type-scalar"></span> Rad
---
# <span class="badge object-type-scalar"></span> Rad

Radiation: rad

## Definition

```python
# Radiation: rad
Rad: typing.Literal["radrad"] = "radrad"
```
